==> naive-ui-2.23.1.tgz: package/es/cascader/styles/light.js <==
import { internalSelectionLight } from '../../_internal/selection/styles';
import { internalSelectMenuLight } from '../../_internal/select-menu/styles';
import { scrollbarLight } from '../../_internal/scrollbar/styles';
import { checkboxLight } from '../../checkbox/styles';
import { commonLight } from '../../_styles/common';
import { createTheme } from '../../_mixins';
import { emptyLight } from '../../empty/styles';
export const self = (vars) => {
    const { borderRadius, boxShadow2, popoverColor, textColor2, textColor3, primaryColor, textColorDisabled, dividerColor, hoverColor, fontSizeMedium, heightMedium } = vars;
    return {
        menuBorderRadius: borderRadius,
        menuColor: popoverColor,
        menuBoxShadow: boxShadow2,
        menuDividerColor: dividerColor,
        menuHeight: 'calc(var(--option-height) * 6.6)',
        optionArrowColor: textColor3,
        optionHeight: heightMedium,
        optionFontSize: fontSizeMedium,
        optionColorHover: hoverColor,
        optionTextColor: textColor2,
        optionTextColorActive: primaryColor,
        optionTextColorDisabled: textColorDisabled,
        optionCheckMarkColor: primaryColor,
        loadingColor: primaryColor,
        columnWidth: '180px'
    };
};
const cascaderLight = createTheme({
    name: 'Cascader',
    common: commonLight,
    peers: {
        InternalSelectMenu: internalSelectMenuLight,
        InternalSelection: internalSelectionLight,
        Scrollbar: scrollbarLight,
        Checkbox: checkboxLight,
        Empty: emptyLight
    },
    self
});
export default cascaderLight;

==> naive-ui-2.34.4.tgz: package/es/cascader/styles/light.js <==
import { internalSelectionLight } from '../../_internal/selection/styles';
import { internalSelectMenuLight } from '../../_internal/select-menu/styles';
import { scrollbarLight } from '../../_internal/scrollbar/styles';
import { checkboxLight } from '../../checkbox/styles';
import { commonLight } from '../../_styles/common';
import { createTheme } from '../../_mixins';
import { emptyLight } from '../../empty/styles';
export const self = (vars) => {
    const { borderRadius, boxShadow2, popoverColor, textColor2, textColor3, primaryColor, textColorDisabled, dividerColor, hoverColor, fontSizeMedium, heightMedium } = vars;
    return {
        menuBorderRadius: borderRadius,
        menuColor: popoverColor,
        menuBoxShadow: boxShadow2,
        menuDividerColor: dividerColor,
        menuHeight: 'calc(var(--n-option-height) * 6.6)',
        optionArrowColor: textColor3,
        optionHeight: heightMedium,
        optionFontSize: fontSizeMedium,
        optionColorHover: hoverColor,
        optionTextColor: textColor2,
        optionTextColorActive: primaryColor,
        optionTextColorDisabled: textColorDisabled,
        optionCheckMarkColor: primaryColor,
        loadingColor: primaryColor,
        columnWidth: '180px'
    };
};
const cascaderLight = createTheme({
    name: 'Cascader',
    common: commonLight,
    peers: {
        InternalSelectMenu: internalSelectMenuLight,
        InternalSelection: internalSelectionLight,
        Scrollbar: scrollbarLight,
        Checkbox: checkboxLight,
        Empty: emptyLight
    },
    self
});
export default cascaderLight;
